# Siemens

This is a placeholder package reserved for open-sourcing the Siemens MkDocs theme.

For other Siemens Open Source projects, see [opensource.siemens.com](https://opensource.siemens.com)
and [github.com/siemens](https://github.com/siemens).
